@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '1.001000';
+our $VERSION = '1.100000';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -21,6 +21,8 @@ Net::AMQP::RabbitMQ - interact with RabbitMQ over AMQP using librabbitmq
 	$mq->connect("localhost", { user => "guest", password => "guest" });
 	$mq->channel_open(1);
 	$mq->publish(1, "queuename", "Hi there!");
+  my $gotten = $mq->get(1, "queuename");
+  print $gotten->{body} . "\n";
 	$mq->disconnect();
 
 =head1 VERSION COMPATIBILITY
@@ -28,7 +30,7 @@ Net::AMQP::RabbitMQ - interact with RabbitMQ over AMQP using librabbitmq
 This module was forked from L<Net::RabbitMQ> version 0.2.6 which uses an older
 version of librabbitmq, and doesn't work correctly with newer versions of RabbitMQ.
 The main change between this module and the original is this library uses
-a newer, unforked, version of librabbitmq. Version 0.4.1 to be precise.
+a newer, unforked, version of librabbitmq. Version 0.7.1 to be precise.
 
 This means this module only works with the AMQP 0.9.1 protocol, so requires RabbitMQ
 version 2+. Also, since the version of librabbitmq used is not a custom fork, it
@@ -41,7 +43,7 @@ and fixes some bugs. It provides a simple wrapper around the librabbitmq library
 that allows connecting, declaring exchanges and queues, binding and unbinding
 queues, publishing, consuming and receiving events.
 
-Error handling in this module is primarily achieve by Perl_croak (die). You
+Error handling in this module is primarily achieve by C<Perl_croak> (die). You
 should be making good use of eval around these methods to ensure that you
 appropriately catch the errors.
 
@@ -50,6 +52,8 @@ appropriately catch the errors.
 All methods, unless specifically stated, return nothing on success
 and die on failure.
 
+Failure to be connected is a fatal failure for most methods.
+
 =head2 new()
 
 Creates a new Net::AMQP::RabbitMQ object.
@@ -199,11 +203,17 @@ C<$body> is the payload to enqueue.
 C<$options> is an optional hash respecting the following keys:
 
      {
-       exchange => $exchange,   #default 'amq.direct'
-       mandatory => $boolean,   #default 0
-       immediate => $boolean,   #default 0
+       exchange => $exchange,                     #default 'amq.direct'
+       mandatory => $boolean,                     #default 0
+       immediate => $boolean,                     #default 0
+       force_utf8_in_header_strings => $boolean,  #default 0
      }
 
+The C<force_utf8_in_header_strings> option causes all headers which look like
+strings to be treated as UTF-8. In an attempt to make this a non-breaking change,
+this option is disabled by default. However, for all headers beginning with
+C<x->, those are treated as UTF-8 regardless of this option (per spec).
+
 C<$props> is an optional hash (the AMQP 'props') respecting the following keys:
 
      {
